--[[
	Description: Configuration used by DataMiner
	Copyright (C) 2014, 2015 Linuz@Proudmore.Eu
    This program is free software; you can redistribute it and/or modify it under the terms of the
	GNU General Public License as published by the Free Software Foundation; either version 2 of the License,
	or (at your option) any later version.
    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
    You should have received a copy of the GNU General Public License along with this program;
	if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
--]]

-- Library references
local L = LibStub("AceLocale-3.0"):GetLocale("DataMiner", true)
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceConfigRegistry = LibStub("AceConfigRegistry-3.0")
local AceConfig = LibStub("AceConfig-3.0")

-- Variables
dm_sc = { -- This list is only in use, if no list is loaded via SavedVariables as example
	{ ["aKey"] = "KRAUT",    ["aCommand"] = "/dm table herbs" },			-- [1]
	{ ["aKey"] = "MINERALE", ["aCommand"] = "/dm table ore" },				-- [2]
	{ ["aKey"] = "ULDUM",    ["aCommand"] = "/dm view zone Uldum" },		-- [3]
	{ ["aKey"] = "SBL",      ["aCommand"] = "/dm view item Silberblatt" },	-- [4]
	{ ["aKey"] = "TITAN",    ["aCommand"] = "/titan gui control" },         -- [5]
}

------------
-- Config --
------------

function GetVersion()
	return tostring(GetAddOnMetadata("TitanDataMiner", "Version"))
end

function GetAuthor()
	return GetAddOnMetadata("TitanDataMiner", "Author")
end

local function GetCategory()
	return GetAddOnMetadata("TitanDataMiner", "X-Category")
end

local function GetLocalizations()
	return GetAddOnMetadata("TitanDataMiner", "X-Localizations")
end

local info = {
	name = "DataMiner",
	type = "group",
	args = {
		cfg_info_desc = {
			order = 1,
			type = "description",
			name = L["Short_Addon_Desc"].."\n\n",
			cmdHidden = true
		},
		cfg_info = {
			name = "Info",
			type = "group", inline = true,
			args = {
				cfg_ver = {
					order = 1,
					type = "description",
					name = COL_GOLD.."Version"..": "..COL_GREEN..GetVersion(),
					cmdHidden = true
				},
				cfg_author = {
					order = 2,
					type = "description",
					name = COL_GOLD..L["Author"]..": "..COL_ORANGE2..GetAuthor(),
					cmdHidden = true
				},
				cfg_cat = {
					order = 3,
					type = "description",
					name = COL_GOLD..L["Category"]..": "..COL_WHITE..GetCategory(),
					cmdHidden = true
				},
				cfg_localizations = {
					order = 4,
					type = "description",
					name = COL_GOLD..L["Localizations"]..": "..COL_WHITE..GetLocalizations(),
					cmdHidden = true
				},
				--cfg_l = {
					--order =	5, name = img,
					--type = "execute", --width = "fill",
					--icon=AddOns\TitanDataMiner\bitmap\us.png
					--func = function() table.insert( dm_sc, {aKey = inc(#dm_sc), aCommand = ""} ) CreateSC() end,
					--cmdHidden = true
				--},
				cfg_license = {
					order = 10,
					type = "description",
					name = COL_GOLD..L["License"]..": "..COL_WHITE.."GPLv2(see license.txt)",
					cmdHidden = true
				},
			}
		},
	}
}

local sc = {  -- the struct will be completed in CreateSC()
	name = L["Chat_Shortcuts"],
	type = "group",
	args = {}
}

local function CreateSC()
	local args = sc.args
	wipe(args)
	for idx, value in pairs(dm_sc) do
		args[tostring(idx)] = {
			type = "group",
			name = value.aKey,	-- left group
			order = idx,
			args = {
				key = {
					order =	1, name = L["Key"],
					type = "input", width = "full",
					get = function() return dm_sc[idx].aKey end,
					set = function( _,value ) dm_sc[idx].aKey = value:upper() CreateSC() end,
					cmdHidden = true
				},
				command = {
					order =	2, name = L["Command"],
					type = "input", width = "full",
					get = function() return dm_sc[idx].aCommand end,
					set = function( _,value ) dm_sc[idx].aCommand = value end,
					cmdHidden = true
				},
				add = {
					order =	3, name = L["Add"],
					type = "execute", width = "fill",
					func = function() table.insert( dm_sc, {aKey = inc(#dm_sc), aCommand = ""} ) CreateSC() end,
					cmdHidden = true
				},
				delete = { 
					order =	4, name = L["Delete"],
					type = "execute", width = "fill",
					func = function() table.remove( dm_sc, tonumber(idx) ) CreateSC() end,
					cmdHidden = true
				}
			},
		}
	end
end

function SetupConfig()
	AceConfig:RegisterOptionsTable("DataMiner", info)
	AceConfigDialog:AddToBlizOptions("DataMiner", "DataMiner")
	CreateSC()
	AceConfig:RegisterOptionsTable(L["Chat_Shortcuts"], sc)
	AceConfigDialog:AddToBlizOptions(L["Chat_Shortcuts"], L["Chat_Shortcuts"], "DataMiner")
end
