--[[
	Description: Constants and tools used by DataMiner
	Copyright (C) 2014, 2015 Linuz@Proudmore.Eu
    This program is free software; you can redistribute it and/or modify it under the terms of the
	GNU General Public License as published by the Free Software Foundation; either version 2 of the License,
	or (at your option) any later version.
    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
    You should have received a copy of the GNU General Public License along with this program;
	if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
--]]

-- Library references
local L = LibStub("AceLocale-3.0"):GetLocale("DataMiner", true)

--[[ not used
function EntryField(length, text, parent)
	local width, height = TitanPanelDMButtonRightClickMenu:GetSize()
	local point, relativeTo, relativePoint, x, y = TitanPanelDMButtonRightClickMenu:GetPoint(1)
	local name = TitanPanelDMButtonRightClickMenu:GetName()
	--print(name, width, height, x, y)
	if (not text) then text = "" end
	if (not length) then length = strlen(text) end
	if (not parent) then parent = UIParent end
	
	local frame = CreateFrame("EditBox", "Entry", parent);
	local backdrop = {
		bgFile = "Interface\\Tooltips\\UI-Tooltip-Background",
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
		tile = false, tileSize = 4, edgeSize = 4,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	}
	
	frame:SetFontObject("GameFontNormal")
	frame:SetBackdrop(backdrop)
	frame:SetBackdropColor(0, 0, 0, 1);
	frame:SetBackdropBorderColor(0.4, 0.4, 0.4)
	frame:SetTextColor(1, 1, 1);
	frame:SetTextInsets(10, 10, 0, 0) --left,right,top,bottom
	frame:SetHeight(26)
	frame:SetWidth(width)--13*length)
	frame:SetPoint("CENTER",x,y)
	frame:SetMaxLetters(length)
	frame:SetText(text)
	return frame;
end
--]]

-------------------------
-- Math, Date and Time --
-------------------------

--Java increment
function inc(i)
	return i + 1
end

--Java decrement
function dec(i)
	return i - 1
end

--not used
--function sleep(sec)
    --socket.select(nil, nil, sec)
--end

-- 1-based indexing
--function bit(p)
	--return 2 ^ (p - 1)
--end

-- Typical call: if hasbit(x, bit(3)) then
--function hasbit(x, p)
	--return x % (p + p) >= p;
--end

--function setbit(x, p)
	--return hasbit(x, p) and x or x + p;
--end

--function clearbit(x, p)
	--return hasbit(x, p) and x - p or x;
--end

-- Bitwise and (a & b)
-- We use this because bit.band seems to be deleted in patch 6.x
function xband( a, b)
    local p, c = 1, 0
    while a > 0 and b > 0 do
        local ra, rb = a%2, b%2
        if ra + rb > 1 then c = c + p end
        a, b, p = (a-ra)/2, (b-rb)/2, p*2
    end
    return c
end

-- Return the TimeSegment we are in
-- count = Segments per a day, so it should be a positive number
function TimeSegment (count)
	return floor( date("%H") / floor (24 / count) ) +1
end

-- toggles a x-state variable
-- states are false-1-2-3-x
function ToggleX ( st, var )
	if (not var) then
		var = 1
	elseif (var == dec(st)) then
		var = false
	else
		var = inc(var)
	end
	return var
end

function Toggle(bool)
	if (bool == true) then return false
	else return true end
end

-------------
-- Strings --
-------------

-- Returns a string with first letter capitalized
local function TitleCase( first, rest )
   return first:upper()..rest:lower()
end

function WordUpper( str )
	return str:gsub( "(%a)([%w_']*)", TitleCase)
end

-- Compares if str starts with start
-- Returns: true or false
function isStart( str, start )
   return string.sub(str,1,string.len(start)) == start
end

-- Compares if str ends with stop
-- Returns: true or false
function isEnd( str, stop )
   return stop == '' or string.sub(str,-string.len(stop)) == stop
end

-------------
-- Tables --
-------------

--Deletes the whole table
function Table_reset(array)
	for i, line in ipairs(array) do
		table.remove(line)
	end
end

-------------
-- Colors --
-------------

COL_BLACK   = "|cff000000"
COL_BLUE    = "|cff0000ff"
COL_GREEN   = "|cff66ff66"
COL_GREEN2  = "|c0070DE5f"
COL_RED     = "|cffff0000"
COL_GOLD    = "|cffffd700"
COL_ORANGE  = "|cffff6600"
COL_ORANGE2 = "|cffff8c00"
COL_YELLOW  = "|cffffff00"
COL_WHITE   = "|cffffffff"

function GetHexColoredText(text, hexcolor)
	if (text and hexcolor) then
		return hexcolor..text.._G["FONT_COLOR_CODE_CLOSE"]
	end
end

-----------------
-- Professions --
-----------------
PROF_HERBALISM      = 182
PROF_MINING         = 186

function HasProfession(prof, p)    --Parameters(PROF_* const, bool)
	local idx1, idx2, arch, fishing, cooking, firstaid = GetProfessions()
	local prof1, icon1, skillLv1, maxSkillLv1, numAbi1, spelloffset1, skillLine1
	local prof2, icon2, skillLv2, maxSkillLv2, numAbi2, spelloffset2, skillLine2
	if (idx1) then
		prof1, icon1, skillLv1, maxSkillLv1, numAbi1, spelloffset1, skillLine1 = GetProfessionInfo(idx1)
		if (prof1 and p) then
			print(prof1)           --Print to Chat for debug
		end
	end
	if (idx2) then
		prof2, icon2, skillLv2, maxSkillLv2, numAbi2, spelloffset2, skillLine2 = GetProfessionInfo(idx2)
		if (prof2 and p) then
			print(prof2)           --Print to Chat for debug
		end
	end
	if ((skillLine1 == prof) or (skillLine2 == prof)) then
		return true
	end
	return false
end

BAG_HERBALISM = 0x0020
BAG_MINING    = 0x0400

-- Is this item in the excluded-list and marked as exclude
local function isExcluded( iId )
	for i, line in ipairs(dm_exclude) do
		if (line.aID == iId) then
			return i, line.aExclude
		end
	end
	return 0, false
end

--Purpose: Test if item is a Herb or Ore
--bagField - Bitwise OR of bag type
function IsHerbOre( itemId, bag )
	local bagField = GetItemFamily(itemId)
	if (xband(bagField, bag) == bag) then
		local idx, excluded = isExcluded(itemId)
		if ( idx > 0 and excluded ) then
			-- This item is in the exclude-list
			return nil
		end
		return true      -- The item fits in the bag, so its the sort we want
	end
	return nil
end
